/* ProparseUtil.java
*/

package com.joanju;

import com.joanju.ProparseLdr;

import java.io.*;

public class ProparseUtil {

	/** Read a config file, which must have a layout like a Windows INI file.
	 * See Proparse's "Configuration Settings" documentation for valid values.
	 * All sections are optional. The following are the default values.
	 * You probably want to at least set the PROPATH.
	 * <pre> 
	 * [BATCH-MODE]
	 * NO
	 * [KEYWORD-ALL]
	 * [OPSYS]
	 * WIN32
	 * [PROPATH]
	 * [PROVERSION]
	 * [WINDOW-SYSTEM]
	 * MS-WIN95
	 * </pre>
	 */
	public static void readConfig(ProparseLdr parser, String inName) throws IOException {
		final int BATCHMODE = 0;
		final int OPSYS = 1;
		final int PROPATH = 2;
		final int PROVERSION = 3;
		final int WINDOWSYSTEM = 4;
		final int KEYWORDALL = 5;

		BufferedReader configFile = new BufferedReader(new FileReader(inName));

		String currLine;
		int currOption = -1;
		int commentLevel = 0;
		while (true) {
			currLine = configFile.readLine();
			if (currLine == null)
				break;
			currLine.trim();
			if (currLine.length()==0)
				continue;
			if (currLine.equals("/*"))
				commentLevel++;
			if (commentLevel == 0 && currLine != "*/") {
				// Currline picks an option
				if      (currLine.equals("[BATCH-MODE]"))	currOption = BATCHMODE;
				else if (currLine.equals("[KEYWORD-ALL]"))	currOption = KEYWORDALL;
				else if (currLine.equals("[OPSYS]"))		currOption = OPSYS;
				else if (currLine.equals("[PROPATH]"))		currOption = PROPATH;
				else if (currLine.equals("[PROVERSION]"))	currOption = PROVERSION;
				else if (currLine.equals("[WINDOW-SYSTEM]"))	currOption = WINDOWSYSTEM;
				// Currline sets an options
				else if (currOption == BATCHMODE)
					parser.configSet("batch-mode", currLine);
				else if (currOption == KEYWORDALL)
					parser.configSet("keyword-all", currLine);
				else if (currOption == OPSYS)
					parser.configSet("opsys", currLine);
				else if (currOption == PROPATH) {
					parser.configSet("propath", currLine);
				}
				else if (currOption == PROVERSION)
					parser.configSet("proversion", currLine);
				else if (currOption == WINDOWSYSTEM)
					parser.configSet("window-system", currLine);
			}
			if (currLine.equals("*/"))  commentLevel--;


		}
		configFile.close();
	} // readConfig

} // ProparseUtil
